elevation_above_stream: Elevation above stream
Description
Calculates the elevation of cells above the nearest downslope stream cell.
Usage
elevation_above_stream(dem, streams, output, verbose_mode = FALSE)
Arguments
streams
Input raster streams file.
verbose_mode
Sets verbose mode. If verbose mode is False, tools will not print output messages.
Value
Returns the tool text outputs.