elevation_above_stream_euclidean: Elevation above stream euclidean
Description
Calculates the elevation of cells above the nearest (Euclidean distance) stream cell.
Usage
elevation_above_stream_euclidean(dem, streams, output,
verbose_mode = FALSE)
Arguments
streams
Input raster streams file.
verbose_mode
Sets verbose mode. If verbose mode is False, tools will not print output messages.
Value
Returns the tool text outputs.