min_downslope_elev_change: Min downslope elev change
Description
Calculates the minimum downslope change in elevation between a grid cell and its eight downslope neighbors.
Usage
min_downslope_elev_change(dem, output, verbose_mode = FALSE)
Arguments
verbose_mode
Sets verbose mode. If verbose mode is False, tools will not print output messages.
Value
Returns the tool text outputs.