Learn R Programming

whitebox (version 2.0.0)

wbt_change_in_contributing_area: Change in contributing area

Description

This tool calculates the downslope rate of change in specific contributing area (SCA).

Usage

wbt_change_in_contributing_area(
  dem,
  output,
  exponent = 1,
  threshold = NULL,
  log = FALSE,
  wd = NULL,
  verbose_mode = FALSE,
  compress_rasters = FALSE
)

Arguments

dem

Name of the input DEM raster file; must be depressionless.

output

Name of the output raster file.

exponent

Optional exponent parameter; default is 1.0.

threshold

Optional convergence threshold parameter, in grid cells; default is infinity.

log

Log-transform the output values?.

wd

Changes the working directory.

verbose_mode

Sets verbose mode. If verbose mode is False, tools will not print output messages.

compress_rasters

Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.

Value

Returns the tool text outputs.