Sets the RGB values of a LiDAR point cloud based on the point classification values.
wbt_colourize_based_on_class(
input,
output = NULL,
intensity_blending = 50,
clr_str = "",
use_unique_clrs_for_buildings = FALSE,
radius = "",
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Name of the input LiDAR points.
Name of the output LiDAR points.
Intensity blending amount (0-100 percent).
Colour values, e.g. 2: (184, 167, 108); 5: #9ab86c.
Use unique colours for each building?.
Search distance used in neighbourhood search.
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.