Learn R Programming

whitebox (version 2.0.0)

wbt_conditional_evaluation: Conditional evaluation

Description

This tool performs a conditional evaluation (if-then-else) operation on a raster.

Usage

wbt_conditional_evaluation(
  input,
  output,
  statement = "",
  true = NULL,
  false = NULL,
  wd = NULL,
  verbose_mode = FALSE,
  compress_rasters = FALSE
)

Arguments

input

Name of the input DEM raster file; must be depressionless.

output

Name of the output raster file.

statement

Conditional statement e.g. value > 35.0. This statement must be a valid Rust statement.

true

Value where TRUE (input raster or constant value).

false

Value where FALSE (input raster or constant value).

wd

Changes the working directory.

verbose_mode

Sets verbose mode. If verbose mode is False, tools will not print output messages.

compress_rasters

Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.

Value

Returns the tool text outputs.