Counts the number of occurrences of a specified value in a cell-stack of rasters.
wbt_count_if(
inputs,
output,
value,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input raster file paths, concatenated with "," or ";". See wbt_file_path() for details.
Output raster file.
Search value (e.g. countif value = 5.0).
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.