Extracts the values of raster(s) at vector point locations.
wbt_extract_raster_values_at_points(
inputs,
points,
out_text = FALSE,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input raster file paths, concatenated with "," or ";". See wbt_file_path() for details.
Input vector points file.
Output point values as text? Otherwise, the only output is to to the points file's attribute table.
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.