Computes geomorphon patterns.
wbt_geomorphons(
dem,
output,
search = 50,
threshold = 0,
tdist = 0,
forms = TRUE,
wd = NULL,
verbose_mode = FALSE,
compress_rasters = FALSE,
command_only = FALSE
)Returns the tool text outputs.
Input raster DEM file.
Output raster file.
Look up distance.
Flatness threshold for the classification function (in degrees).
Distance (in cells) to begin reducing the flatness threshold to avoid problems with pseudo-flat lines-of-sight.
Classify geomorphons into 10 common land morphologies, else, output ternary code.
Changes the working directory.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages.
Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
Return command that would be executed by system() rather than running tool.