Divides a landscape into nearly equal sized drainage basins (i.e. watersheds).
wbt_isobasins(
dem,
output,
size,
connections = FALSE,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input raster DEM file.
Output raster file.
Target basin size, in grid cells.
Output upstream-downstream flow connections among basins?.
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.