Evaluates whether the values in a raster are normally distributed.
wbt_ks_test_for_normality(
input,
output,
num_samples = NULL,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input raster file path. See wbt_file_path() for details.
Output HTML file.
Number of samples. Leave blank to use whole image.
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.