Classifies the values in one LiDAR point cloud that correspond with points in a subset cloud.
wbt_lidar_classify_subset(
base,
subset,
output,
subset_class,
nonsubset_class = NULL,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input base LiDAR file.
Input subset LiDAR file.
Output LiDAR file.
Subset point class value (must be 0-18; see LAS specifications).
Non-subset point class value (must be 0-18; see LAS specifications).
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.