Thins a LiDAR point cloud, reducing point density.
wbt_lidar_thin(
input,
output,
resolution = 2,
method = "lowest",
save_filtered = FALSE,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input LiDAR file.
Output LiDAR file.
The size of the square area used to evaluate nearby points in the LiDAR data.
Point selection method; options are 'first', 'last', 'lowest' (default), 'highest', 'nearest'.
Save filtered points to separate file?.
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.