Calculates the surface roughness for points over a range of spatial scales.
wbt_multiscale_std_dev_normals_signature(
dem,
points,
output,
min_scale = 1,
step = 1,
num_steps = 10,
step_nonlinearity = 1,
wd = NULL,
verbose_mode = NULL,
compress_rasters = NULL,
command_only = FALSE
)Returns the tool text outputs.
Input raster DEM file.
Input vector points file.
Output HTML file.
Minimum search neighbourhood radius in grid cells.
Step size as any positive non-zero integer.
Number of steps.
Step nonlinearity factor (1.0-2.0 is typical).
Changes the working directory. Default: NULL will use the value in WhiteboxTools settings, see wbt_wd() for details.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages. Default: NULL will use the value in WhiteboxTools settings, see wbt_verbose() for details.
Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters. Default: NULL will use the value in WhiteboxTools settings, see wbt_compress_rasters() for details.
Return command that would be executed by system() rather than running tool. Default: FALSE.