Learn R Programming

whitebox (version 2.1.5)

wbt_multiscale_topographic_position_image: Multiscale topographic position image

Description

Creates a multiscale topographic position image from three DEVmax rasters of differing spatial scale ranges.

Usage

wbt_multiscale_topographic_position_image(
  local,
  meso,
  broad,
  output,
  lightness = 1.2,
  wd = NULL,
  verbose_mode = FALSE,
  compress_rasters = FALSE,
  command_only = FALSE
)

Value

Returns the tool text outputs.

Arguments

local

Input local-scale topographic position (DEVmax) raster file.

meso

Input meso-scale topographic position (DEVmax) raster file.

broad

Input broad-scale topographic position (DEVmax) raster file.

output

Output raster file.

lightness

Image lightness value (default is 1.2).

wd

Changes the working directory.

verbose_mode

Sets verbose mode. If verbose mode is FALSE, tools will not print output messages.

compress_rasters

Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.

command_only

Return command that would be executed by system() rather than running tool.