Learn R Programming

whitebox (version 2.1.5)

wbt_ruggedness_index: Ruggedness index

Description

Calculates the Riley et al.'s (1999) terrain ruggedness index from an input DEM.

Usage

wbt_ruggedness_index(
  dem,
  output,
  zfactor = NULL,
  wd = NULL,
  verbose_mode = FALSE,
  compress_rasters = FALSE,
  command_only = FALSE
)

Value

Returns the tool text outputs.

Arguments

dem

Input raster DEM file.

output

Output raster file.

zfactor

Optional multiplier for when the vertical and horizontal units are not the same.

wd

Changes the working directory.

verbose_mode

Sets verbose mode. If verbose mode is FALSE, tools will not print output messages.

compress_rasters

Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.

command_only

Return command that would be executed by system() rather than running tool.