This tool calculates the downslope rate of change in specific contributing area (SCA).
wbt_change_in_contributing_area(
dem,
output,
exponent = 1,
threshold = NULL,
log = FALSE,
wd = NULL,
verbose_mode = FALSE,
compress_rasters = FALSE
)Name of the input DEM raster file; must be depressionless.
Name of the output raster file.
Optional exponent parameter; default is 1.0.
Optional convergence threshold parameter, in grid cells; default is infinity.
Log-transform the output values?.
Changes the working directory.
Sets verbose mode. If verbose mode is False, tools will not print output messages.
Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
Returns the tool text outputs.