Classifies or filters LAS points in regions of overlapping flight lines.
wbt_classify_overlap_points(
input,
output,
resolution = 2,
filter = FALSE,
wd = NULL,
verbose_mode = FALSE,
compress_rasters = FALSE,
command_only = FALSE
)Returns the tool text outputs.
Input LiDAR file.
Output LiDAR file.
The size of the square area used to evaluate nearby points in the LiDAR data.
Filter out points from overlapping flightlines? If false, overlaps will simply be classified.
Changes the working directory.
Sets verbose mode. If verbose mode is FALSE, tools will not print output messages.
Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
Return command that would be executed by system() rather than running tool.