This tool performs a conditional evaluation (if-then-else) operation on a raster.
wbt_conditional_evaluation(
input,
output,
statement = "",
true = NULL,
false = NULL,
wd = NULL,
verbose_mode = FALSE,
compress_rasters = FALSE
)Name of the input DEM raster file; must be depressionless.
Name of the output raster file.
Conditional statement e.g. value > 35.0. This statement must be a valid Rust statement.
Value where TRUE (input raster or constant value).
Value where FALSE (input raster or constant value).
Changes the working directory.
Sets verbose mode. If verbose mode is False, tools will not print output messages.
Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
Returns the tool text outputs.